# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com),
and this project adheres to
[Semantic versioning](https://semver.org/spec/v2.0.0.html).

Fresh changes should be at the beginning

## 0.1.0 Join the world (10-05-2020)

This release is focused on project initial CI/CD configuration. All related
issues and pull requests can be found in first
[closed project](https://github.com/insspb/ikt/projects/1).

### New features or options that was not exist before:

* Added: Readme, Code of conduct and Contributing guide (#25)
[@insspb](https://github.com/insspb)
* Added: Integration with pypi.org for auto deploy on new repo tag (#22)
[@insspb](https://github.com/insspb)
* Added: Pytest tests and nox workflows, including linting (#21)
[@insspb](https://github.com/insspb)
* Added: Pre-commit configuration and github actions workflow with black and
other linting tools (#20) [@insspb](https://github.com/insspb)
* Added: Release drafter for automatically changelog generation (#18)
[@insspb](https://github.com/insspb)
* Added: Issues and pull request templates (#17)
[@insspb](https://github.com/insspb)
* Added: Empty package suitable for pip publishing without errors (#16)
[@insspb](https://github.com/insspb)
* Added: License file #1 (#15) [@insspb](https://github.com/insspb)
* Added: Sphinx documentation build and integration with readthedocs (#13)
[@insspb](https://github.com/insspb)
